@@ -62,11 +62,17 @@ class ListToUrnConversionStep(Step):
                   'machine name / API Key value %s and matching against '
                   'a Trade Item and/or Company in the master data '
                   'configuration', pool)
-        cp_length = DBProxy().get_company_prefix_length(pool)
+        try:
+            cp_length = DBProxy().get_company_prefix_length(pool)
+        except DBProxy.InvalidBarcode:
+            logger.debug('Invalid barcode, this may be an indicator /'
+                         ' company prefix format...trying')
+            cp_length = len(pool) - 1
         rule_context.context['company_prefix_length'] = cp_length
         # if we are dealing with gtins we need to make urn values sans the
         # epc declaration
         return_vals = []
+        rule_context.context['pool'] = pool
         if len(pool) == 14:
             converter = self.handle_gtins(cp_length, data, return_vals, pool,
                                           rule_context)
@@ -76,9 +82,11 @@ class ListToUrnConversionStep(Step):
             rule_context.context['item_reference'] = converter.item_reference
             rule_context.context[
                 'saleable_unit_flag'] = 1 if converter.indicator_digit == '0' else 0
-        elif len(pool) == 18:
-            self.handle_ssccs(cp_length, data, return_vals, pool)
-
+        else:
+            converter = self.handle_ssccs(cp_length, data, return_vals, pool)
+            rule_context.context['company_prefix'] = converter.company_prefix
+            rule_context.context['indicator_digit'] = converter.extension_digit
+            rule_context.context['is_sscc'] = converter.extension_digit
         return return_vals
 
     def handle_gtins(self, cp_length, numbers, return_vals, pool,
@@ -103,6 +111,7 @@ class ListToUrnConversionStep(Step):
         rule_context.context['trade_item'] = TradeItem.objects.get(
             GTIN14=pool
         )
+        numbers = self.get_number_list(numbers)
         self.info('Formatting for GTIN response.')
         # provide a dummy serial number so we can just quickly parse the company prefix
         converter = BarcodeConverter(
@@ -118,8 +127,69 @@ class ListToUrnConversionStep(Step):
             )
         return converter
 
+    def get_number_list(self, numbers):
+        """
+        Converts a sequential start/end to a list of numbers for processing.
+        Leaves random lists alone
+        :param numbers: The numbers to inspect and possibly convert to a list.
+        :return: A list of numbers
+        """
+        # if the below evaluates to true then we know we are dealing with
+        # a sequential reply.  In that case, we transform the start and
+        # end numbers into a list using the range function, otherwise
+        # we leave the list alone
+        if len(numbers) == 2 and numbers[0] - numbers[1] != 1:
+            self.info('Sequential pool detected, converting to list.')
+            numbers = range(numbers[0], numbers[1] + 1)
+        else:
+            self.info('Random pool detected.')
+        return numbers
+
     def handle_ssccs(self, cp_length, numbers, return_vals, sb_response):
-        raise NotImplementedError('handle_ssccs is not currently implemented.')
+        serial_length = 16 - cp_length
+        converter = None
+        try:
+            converter = BarcodeConverter('00%s' % (sb_response), cp_length)
+            company_prefix = converter.company_prefix
+            extension_digit = converter.extension_digit
+        except (DBProxy.InvalidBarcode, BarcodeConverter.BarcodeNotValid):
+            logger.info('Data was not sent as a barcode...trying '
+                        'extension digit / company prefix format')
+            company_prefix = sb_response[1:]
+            extension_digit = sb_response[:1]
+            serial_length = 16 - len(company_prefix)
+
+        numbers = self.get_number_list(numbers)
+        for number in numbers:
+            return_vals.append(
+                self.format_sscc_urn(
+                    company_prefix,
+                    extension_digit,
+                    number,
+                    serial_length
+                )
+            )
+        if not converter:
+            class Converter:
+                pass
+            converter = Converter()
+            converter.company_prefix = company_prefix
+            converter.extension_digit = extension_digit
+        return converter
+
+    def format_sscc_urn(self, company_prefix, extension_digit, number,
+                        serial_length):
+        """
+        Creates SSCC EPC Urns.  Override to change the behavior or format.
+        :param company_prefix: The company prefix
+        :param extension_digit: The SSCC extension digit
+        :param number: The serial number for the SSCC.
+        :return: A properly formatted EPC SSCC URN value.
+        """
+        return '%s%s.%s%s' % (
+            'urn:epc:id:sscc:', company_prefix, extension_digit,
+            str(number).zfill(serial_length)
+        )
 
     def format_gtin_urn(self, company_prefix: str, indicator: str,
                         item_reference: str, serial_number: str):
@@ -136,6 +206,10 @@ class ListToUrnConversionStep(Step):
             serial_number
         )
 
+    def foramt_sscc_urn(self, company_prefix: str, extension: str,
+                        serial_number: str):
+        pass
+
     def on_failure(self):
         pass
 
@@ -323,7 +397,8 @@ class ListToBarcodeConversionStep(Step):
             executing rule.
         :return: None
         """
-        sequential = Pool.objects.prefetch_related('sequentialregion_set').filter(
+        sequential = Pool.objects.prefetch_related(
+            'sequentialregion_set').filter(
             machine_name=pool
         ).count()
         if self.company_prefix == '':
@@ -378,12 +453,11 @@ class ListToBarcodeConversionStep(Step):
             'SSCC App Identifier': 'True or False- whether or not to include '
                                    'the Application Identifier for SSCC values'
                                    ' in the response.',
-            'Extension Digit':'The extension digit for SSCCs (does not apply '
-                              'to GTINs.',
-            'Company Prefix':'The company prefix must be supplied for handling'
-                             ' SSCC values.',
+            'Extension Digit': 'The extension digit for SSCCs (does not apply '
+                               'to GTINs.',
+            'Company Prefix': 'The company prefix must be supplied for handling'
+                              ' SSCC values.',
         }
 
-
     class InvalidCompanyPrefix(Exception):
         pass
